microsandbox-runtime 0.6.5

Runtime library for the microsandbox sandbox process and microVM entry points.
microsandbox-runtime-0.6.5 has been yanked.

microsandbox-runtime provides the runtime library for the sandbox process entry point. This crate contains the unified VM + relay logic that runs inside the single sandbox process.